@@ -256,7 +256,8 @@ void chat_webpage(void){
   @   fromcli: %h(PB("cli")?"true":"false"),
   @   alertSound: "%h(zAlert)",
   @   initSize: %d(db_get_int("chat-initial-history",50)),
-  @   imagesInline: !!%d(db_get_boolean("chat-inline-images",1))
+  @   imagesInline: !!%d(db_get_boolean("chat-inline-images",1)),
+  @   pollTimeout: %d(db_get_int("chat-poll-timeout",420))
   @ };
   ajax_emit_js_preview_modes(0);
   chat_emit_alert_list();
@@ -1204,7 +1205,7 @@ void chat_msg_from_event(
 **                               previously undownloaded content is retrieved.
 **        --debug                Additional debugging output
 **        --out DATABASE         Store CHAT table in separate database file
-**                               DATABASE rather that adding to local clone
+**                               DATABASE rather than adding to local clone
 **        --unsafe               Allow the use of unencrypted http://
 **
 ** > fossil chat send [ARGUMENTS]
